pub enum Event {
Exit,
Input(String),
ForceSubmitQueued,
Continue,
}Expand description
Application state level events that can come from the UI
Variants
Exit
Exit requested
Input(String)
User submitted a message as input
ForceSubmitQueued
Force submitting all queued prompts right now
Continue
Submit the current state without a new user message (e.g. continue a resumed session)